Welcome to the documentation of the Geological Toolbox! — Geological Toolbox 0.1.0b documentation

# Welcome to the documentation of the Geological Toolbox!

Contents:

- 1. The GeologicalToolbox API reference
  - 1.1. Members of the ‘GeologicalToolbox’ package
  - 1.2. Members of the ‘GeologicalToolbox.AbstractLog’ module
  - 1.3. Constants defined in the ‘GeologicalToolbox’ package
  - 1.4. Members of the ‘GeologicalToolbox.DBHandler’ module
  - 1.5. Exceptions defined for the API
  - 1.6. Members of the ‘GeologicalToolbox.Geometries’ module
  - 1.7. Members of the ‘GeologicalToolbox.GeoObject’ module
  - 1.8. Members of the ‘GeologicalToolbox.Properties’ module
  - 1.9. Members of the ‘GeologicalToolbox.Requests’ module
  - 1.10. Members of the ‘GeologicalToolbox.Stratigraphy’ module
  - 1.11. Members of the ‘GeologicalToolbox.WellLogs’ module
  - 1.12. Members of the ‘GeologicalToolbox.Wells’ module
- 2. The GeologicalToolbox API reference
  - 2.1. Unittest for the ‘GeologicalToolbox.GeoPoint’ class
  - 2.2. Unittest for the ‘GeologicalToolbox.Line’ class
  - 2.3. Unittest for the ‘GeologicalToolbox.PropertyLogs’ module
  - 2.4. Unittest for the ‘GeologicalToolbox.StratigraphicObject’ module
  - 2.5. Unittest for the ‘GeologicalToolbox.Wells’ module

## TODO List

Todo

- reformat docstrings, espacially of setter and getter functions
- check exception types

(The original entry is located in /Users/stephan/GeologicalToolbox/GeologicalToolbox/AbstractLog.py:docstring of GeologicalToolbox.AbstractLog, line 3.)

Todo

- reformat docstrings, espacially of setter and getter functions
- check exception types

(The original entry is located in /Users/stephan/GeologicalToolbox/GeologicalToolbox/Properties.py:docstring of GeologicalToolbox.Properties, line 4.)

Todo

- Integrate functionality
- define interpolation methods
- define return statement

(The original entry is located in /Users/stephan/GeologicalToolbox/GeologicalToolbox/Requests.py:docstring of GeologicalToolbox.Requests.Requests.interpolate_geopoints, line 3.)

Todo

- reformat docstrings, espacially of setter and getter functions
- check exception types

(The original entry is located in /Users/stephan/GeologicalToolbox/GeologicalToolbox/WellLogs.py:docstring of GeologicalToolbox.WellLogs, line 4.)

Todo

- reformat docstrings, especially of setter and getter functions
- check exception types

(The original entry is located in /Users/stephan/GeologicalToolbox/GeologicalToolbox/Wells.py:docstring of GeologicalToolbox.Wells, line 3.)

## Indices and tables

- Index
- Module Index
- Search Page